function rbf = getRbf(type, varargin)
% GETRBF Returns a strictly positive definite RBF kernel.
%   rbf  =  GETRBF(type) returns a function handle representing the radial
%   kernel of type 'type'.
%   The handled function is in the form
%       rbf(ep, r)
%   where ep is the shape parameter and r is the radial variable.
%   Additional parameters (d, k) are required for the Wendland kernels. 
%
%   See also getWen


switch type
    case 'gauss'
        rbf = @(ep, r) exp(-(ep*r).^2);
    case 'imq'
        rbf = @(ep, r) 1./sqrt(1+(ep*r).^2);
    case 'wen'
        if nargin ~= 3
            error('Wendland kernels: getRbf("wen", d, k)')
        else
            rbf = getWen(varargin{1}, varargin{2});
        end
    otherwise
        error(['RBF "' type '" not available'])
end