function dataset = setData(X, f, par)
% dataset = SETDATA(X, f, par) creates a train/val/test dataset.


% Decide sizes
M = size(X, 1);
Mte = floor(M * par.percTe);
Mtr = M - Mte;

% Permute data
X = X(par.perm, :);
f = f(par.perm, :);

% Training set (including validation)
Xtr = X(1 : Mtr, :);
ftr = f(1 : Mtr, :);

% Indexes for k-fold cross validation
par.k = min(par.k, Mtr); % move to LOOCV is dataset is small
MSubsample = floor(Mtr / par.k);
indVal = zeros(par.k, 2);
indVal(:, 1) = MSubsample * (0 : par.k - 1) + 1;
indVal(:, 2) = MSubsample * ( 1 : par.k);
indVal(end, 2) = Mtr;


% Compute normalization variables
if strcmp(par.normalization, 'uniform')
    translXtr = min(Xtr);
    scaleXtr =  max(Xtr) - min(Xtr);
    translFtr = min(ftr);
    scaleFtr = max(ftr) - min(ftr);
elseif strcmp(par.normalization, 'none')
    translXtr = 0;
    scaleXtr = 1;
    translFtr = 0;
    scaleFtr = 1;
else
    error('Specify a valid normalization type')
end

% Avoid dividing by zero
scaleXtr(scaleXtr == 0) = 1;
scaleFtr(scaleFtr == 0) = 1;

% Normalize
Xtr = bsxfun(@rdivide, bsxfun(@minus, Xtr, translXtr), scaleXtr);
ftr = bsxfun(@rdivide, bsxfun(@minus, ftr, translFtr), scaleFtr);


% Set up output
dataset.Xtr = Xtr;
dataset.ftr = ftr;
dataset.translXtr = translXtr;
dataset.scaleXtr = scaleXtr;
dataset.translFtr = translFtr;
dataset.scaleFtr = scaleFtr;
dataset.indVal = indVal;
dataset.Xte = X(end - Mte + 1: end, :);
dataset.fte = f(end - Mte + 1: end, :);

end